## 0.4.0.6 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.4.0.5 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 0.4.0.4 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 0.4.0.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.4.0.2 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.4.0.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.4.0.0 (2023-01-06)

Add stubs for `pyasn1` (#9437)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

